# If there are this code in orther local have to use 
# from lazyearth.mainfile import objearth
# from lazyearth.mainfile import water

from lazyearth.mainfile import objearth
from lazyearth.mainfile import water
from lazyearth.mainfile import imagedataset

__author__  = 'tul kedsaro'
__email__   = 'Tun.k@ku.th'
__version__ = '1.0.25'
print(f'Lazyearth version : {__version__} Krub')

